@@ -196,7 +196,7 @@ class ExportManager:
 			dest = fmt.create_export_path(name=name, root=root, payload=payload) if path is None else Path(path)
 			try:
 				return cls._export_fmt(fmt, payload, dest, **kwargs)
-			except fmt.ExportFailedError:
+			except fmt._ExportFailedError:
 				pass
 
 		raise cls.ExportFailedError(payload, fmts)
@@ -223,7 +223,7 @@ class ExportManager:
 			dest = fmt.create_export_path(name=name, root=root) if path is None else Path(path)
 			try:
 				return cls._load_export_fmt(fmt, dest, **kwargs)
-			except fmt.LoadFailedError:
+			except fmt._LoadFailedError:
 				pass
 
 		raise cls.LoadFailedError(path, fmts)
@@ -286,6 +286,10 @@ def load_export(name=None, root=None, *, fmt=None, path=None, manager=None, **kw
 
 
 
+class LoadFailedError(ValueError): pass
+class ExportFailedError(ValueError): pass
+
+
 class Exporter:
 	@classmethod
 	def validate_export_obj(cls, obj: Any) -> bool:
@@ -356,9 +360,8 @@ class Exporter:
 		options = getattr(cls, '_my_export_extensions', None)
 		return root / f'{name}{"" if options is None else options[0]}'
 
-
-	class LoadFailedError(ValueError): pass
-	class ExportFailedError(ValueError): pass
+	_LoadFailedError = LoadFailedError
+	_ExportFailedError = ExportFailedError
 
 	@staticmethod
 	def _load_export(path: Path, src: Type['ExportManager']) -> Any:
