@@ -1,6 +1,8 @@
 
 # from omnibelt import safe_self_execute
 
+from typing import Iterator, Hashable
+
 from collections import OrderedDict
 
 def sign(x):
@@ -34,6 +36,15 @@ def split_dict(items, keys):
 
 
 
+def filter_duplicates(*iterators: Iterator[Hashable]):
+	seen = set()
+	for itr in iterators:
+		for x in itr:
+			if x not in seen:
+				seen.add(x)
+				yield x
+
+
 
 
 
